@@ -36,7 +36,7 @@ import sqlite3
 import struct
 
 from peewee import *
-from peewee import Expr
+from peewee import Expression
 from peewee import QueryCompiler
 from peewee import R
 from peewee import transaction
@@ -223,7 +223,8 @@ class SqliteExtDatabase(SqliteDatabase):
     def create_index(self, model_class, field_name, unique=False):
         if issubclass(model_class, FTSModel):
             return
-        return super(SqliteExtDatabase, self).create_index(model_class, field_name, unique)
+        return super(SqliteExtDatabase, self).create_index(
+            model_class, field_name, unique)
 
     def granular_transaction(self, lock_type='deferred'):
         assert lock_type.lower() in ('deferred', 'immediate', 'exclusive')
@@ -257,7 +258,7 @@ SqliteExtDatabase.register_ops({
 })
 
 def match(lhs, rhs):
-    return Expr(lhs, OP_MATCH, rhs)
+    return Expression(lhs, OP_MATCH, rhs)
 
 # Shortcut for calculating ranks.
 Rank = lambda model: fn.rank(fn.matchinfo(R(model._meta.db_table)))
